@@ -15,10 +15,9 @@ CONTEXT_SETTINGS = dict(max_content_width=click.get_terminal_size()[0], terminal
 
 
 @click.group(context_settings=CONTEXT_SETTINGS)
-@click.option("-c", "--config", help="""Temporary configuration to use. To use environment config:
-echo \"export CLOUDINARY_URL=YOUR_CLOUDINARY_URL\" >> ~/.bash_profile && source ~/.bash_profile
+@click.option("-c", "--config", help="""Tell the CLI which account to run the command on by specifying an account environment variable. 
 """)
-@click.option("-C", "--config_saved", help="""Saved configuration to use - see `config` command""")
+@click.option("-C", "--config_saved", help="""Tell the CLI which account to run the command on by specifying a saved configuration - see `config` command.""")
 @click_log.simple_verbosity_option(logger)
 def cli(config, config_saved):
     if config:
